#ifndef _EINA_CXX_SUITE_H
#define _EINA_CXX_SUITE_H

#include <cassert>
#include <algorithm>

#include <check.h>
#include "../efl_check.h"

#endif /* _EINA_CXX_SUITE_H */
